onMessageRead property
Callback when a message has been displayed for the first time only
Implementation
final ValueSetter<Message>? onMessageRead;
Callback when a message has been displayed for the first time only
final ValueSetter<Message>? onMessageRead;