copyWith method
Creates a copy of this controller with the same current category.
Implementation
EmojiPickerController copyWith({Category? category}) {
return EmojiPickerController(initialCategory: category ?? _currentCategory);
}
Creates a copy of this controller with the same current category.
EmojiPickerController copyWith({Category? category}) {
return EmojiPickerController(initialCategory: category ?? _currentCategory);
}