EmojiPickerUtils class

Helper class that provides extended usage

Constructors

EmojiPickerUtils()
Singleton Constructor
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addEmojiToRecentlyUsed({required GlobalKey<EmojiPickerState> key, required Emoji emoji, Config config = const Config()}) Future<void>
Add an emoji to recently used list or increase its counter
applyDisplaySkinTone(Emoji emoji, SkinToneConfig skinToneConfig, String? rememberedSkinTone) Emoji
Returns the emoji that should be displayed (and selected) in the grid, recents and search results.
applySkinTone(Emoji emoji, String color) Emoji
Applies skin tone to given emoji
clearRecentEmojis({required GlobalKey<EmojiPickerState> key}) Future<void>
Clears the list of recent emojis
extractSkinTone(Emoji emoji) String?
Returns the skin tone modifier contained in emoji, or null when the emoji carries no skin tone.
filterUnsupported(List<CategoryEmoji> data) Future<List<CategoryEmoji>>
Filters out emojis not supported on the platform
getEmojiRegex() RegExp
Returns the emoji regex Based on https://unicode.org/reports/tr51/
getRecentEmojis() Future<List<RecentEmoji>>
Returns list of recently used emoji from cache
getRememberedSkinTone() Future<String?>
Returns the last remembered skin tone modifier, or null if none.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeSkinTone(Emoji emoji) Emoji
Removes any skin tone modifier from the given emoji
searchEmoji(String search, List<CategoryEmoji> emojiSet, {bool checkPlatformCompatibility = true}) Future<List<Emoji>>
Search for related emoticons based on keywords
setEmojiTextStyle(String text, {required TextStyle emojiStyle, TextStyle? parentStyle}) List<InlineSpan>
Produce a list of spans to adjust style for emoji characters. Spans enclosing emojis will have parentStyle combined with emojiStyle. Other spans will not have an explicit style (this method does not set parentStyle to the whole text.
setRememberedSkinTone(String? skinTone) Future<void>
Persists the remembered skin tone modifier. Passing null clears it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited