reactionWidgetDecoration property
Used for giving decoration reaction widget in bottom sheet.
Implementation
final BoxDecoration? reactionWidgetDecoration;
Used for giving decoration reaction widget in bottom sheet.
final BoxDecoration? reactionWidgetDecoration;