lastSeenAgoBuilder property

LastSeenAgoBuilder? lastSeenAgoBuilder
final

Just like Instagram messages receipts are displayed at the bottom of last message. If in case you want to modify it using your custom widget you can utilize this function.

Implementation

final LastSeenAgoBuilder? lastSeenAgoBuilder;