autoDismissOnSelection property
If true, the suggestion popup will be dismissed automatically when a suggestion is selected.
Implementation
final bool autoDismissOnSelection;
If true, the suggestion popup will be dismissed automatically when a suggestion is selected.
final bool autoDismissOnSelection;