suggestionItemType property
Defines the type of suggestion items, whether they are scrollable or not.
Implementation
final SuggestionItemsType suggestionItemType;
Defines the type of suggestion items, whether they are scrollable or not.
final SuggestionItemsType suggestionItemType;