updateCategory method
Internal method used by EmojiPicker to update the controller when the user manually changes categories.
This should not be called directly by user code.
Implementation
void updateCategory(Category category) {
if (_currentCategory != category) {
_currentCategory = category;
notifyListeners();
}
}